@@ -19,7 +19,7 @@ from matplotlib import pyplot as plt
 
 from cliff.command import Command
 
-from joule import LocalNumpyPipe
+from joule import LocalPipe
 from nilm.readers import capture
 from nilm.meter import meter
 from nilm.meter.utils import MeterConfigurationError
@@ -92,9 +92,9 @@ class ScopeCmd(Command):
 
         # pipes to receive data
         if(my_meter['type'] == 'contact'):
-            npipe = LocalNumpyPipe("raw", layout="uint16_6")
+            npipe = LocalPipe("uint16_6",name="raw")
         else:
-            npipe = LocalNumpyPipe("raw", layout="int16_8")
+            npipe = LocalPipe("int16_8", name="raw")
 
         # capture reader
         config = {
