@@ -1,14 +1,10 @@
-import joule.utils.time
 import numpy as np
 import bisect
 import json
-from joule.utils.time import timestamp_to_human
-from joule import FilterModule, yesno
+from joule import FilterModule, utilities
 
-import logging
 import scipy.fftpack  # fftpack fft??
 import asyncio
-import sys
 from . import helpers
 
 ARGS_DESC = """
@@ -186,7 +182,7 @@ class Prep(FilterModule):
     def custom_args(self, parser):
         parser.add_argument("--current-indices", required=True, type=json.loads,
                             help="up to 3 current elements (1 indexed)")
-        parser.add_argument("--rotations", required=True, type=json,
+        parser.add_argument("--rotations", required=True, type=json.loads,
                             help="voltage angle for each current (radians)")
         parser.add_argument("--nshift", type=int, default=1,
                             help="amount to shift each window")
@@ -194,29 +190,34 @@ class Prep(FilterModule):
                             help="number of odd harmonics to compute"),
         parser.add_argument("--scale-factor", type=float, default=1.0,
                             help="scale to watts (RMS voltage)")
-        parser.add_argument("--merge", type=yesno, default=True,
+        parser.add_argument("--merge", type=utilities.yesno, default=True,
                             help="use a single output stream for all phases")
-        parser.add_argument("--polar", type=yesno, default=False,
+        parser.add_argument("--polar", type=utilities.yesno, default=False,
                             help="use polar coordinates (mag, angle) or cartesian (P,Q)")
         parser.description = ARGS_DESC
 
-    async def run(self, parsed_args, inputs, outputs, nrows=0):
+    n_output = 0
+    async def run(self, parsed_args, inputs, outputs):
         nphases = len(parsed_args.current_indices)
         try:
             iv = inputs['iv']
             zc = inputs['zero_crossings']
-            if(parsed_args.merge):
+            if parsed_args.merge:
                 output = outputs['prep']
+                output.name = 'prep_watched'
+                output.enable_cache(60)  # 1 out per second
+
             else:
                 # expect prep-a, prep-b, prep-c output streams
                 ph_outputs = []
                 for ph in range(nphases):
-                    ph_outputs.append(outputs['prep-%c' % ('abc'[ph])])
+                    output_pipe = outputs['prep-%c' % ('abc'[ph])]
+                    output_pipe.enable_cache(60)
+                    ph_outputs.append(output_pipe)
         except KeyError as e:
             raise helpers.FilterError("required inputs [iv, zero_crossings], outputs [prep] (or [prep-a,...])")
-            
-        rows_processed = 0
-        while(True):
+
+        while True:
             iv_data = await iv.read(flatten=True)
             zc_data = await zc.read(flatten=True)
             # print("iv [%d]  %s->%s" % (len(iv_data), timestamp_to_human(iv_data[0, 0]),
@@ -230,35 +231,36 @@ class Prep(FilterModule):
             scale_factor = parsed_args.scale_factor
             rows = iv_data.shape[0]
             data_timestamps = iv_data[:, 0]
-            zc_timestamps = zc_data[:,0]
+            zc_timestamps = zc_data[:, 0]
             # check to make sure the the zc data overlaps with iv data
             # if we lose a voltage signal iv stalls looking for zc data
             # flush the old iv data because there are not any zc's for it
 
-            if(min(zc_timestamps) > max(data_timestamps)):
+            if min(zc_timestamps) > max(data_timestamps):
                 print("no zero crossings, dumping iv data")
                 iv.consume(len(iv_data))
                 continue
-            
             if rows < 2:
                 continue  # go back and get more data before we run
 
-            last_inserted = [joule.utils.time.min_timestamp]
+            last_inserted = None #[joule.utils.time.min_timestamp]
 
             async def insert_if_nonoverlapping(data):
                 """Call insert_function to insert data, but only if this
                 data doesn't overlap with other data that we inserted."""
-                if data[0][0] <= last_inserted[0]:
+                nonlocal last_inserted
+                #                if data[0][0] <= last_inserted[0]:
+                if last_inserted is not None and data[0][0] <= last_inserted:
                     return
-                last_inserted[0] = data[-1][0]
-                if(parsed_args.merge):
+                last_inserted = data[-1][0]
+                if parsed_args.merge:
                     await output.write(data)
                 else:
-                    width = nharm*2
+                    width = nharm * 2
                     for ph in range(nphases):
-                        start_i = 1+ph*width
-                        end_i = start_i+width
-                        cols = [0]+list(range(start_i, end_i))
+                        start_i = 1 + ph * width
+                        end_i = start_i + width
+                        cols = [0] + list(range(start_i, end_i))
                         await ph_outputs[ph].write(data[:, cols])
 
             processed = 0
@@ -281,8 +283,8 @@ class Prep(FilterModule):
                     if idx_min >= idx_max or idx_max >= len(data_timestamps):
                         return None
                     time_lag = (data_timestamps[
-                                idx_min] - t_min) / (t_max - t_min)
-                    lag_correction = np.e**(2 * 1j * np.pi * time_lag)
+                                    idx_min] - t_min) / (t_max - t_min)
+                    lag_correction = np.e ** (2 * 1j * np.pi * time_lag)
 
                     # Perform FFT over those indices
                     N = idx_max - idx_min
@@ -301,11 +303,11 @@ class Prep(FilterModule):
                         out[0, 0] = round(t_min)
                         for k in range(nharm):
                             Fk = F[2 * k + 1] * \
-                                np.e**(rot * 1j * (2 * k + 1)) / lag_correction
+                                 np.e ** (rot * 1j * (2 * k + 1)) / lag_correction
                             # compute output values
                             if parsed_args.polar:
                                 out_a = np.abs(Fk) * scale_factor  # VA
-                                out_b = (np.angle(Fk)+np.pi/2)*2/np.pi  # pf
+                                out_b = (np.angle(Fk) + np.pi / 2) * 2 / np.pi  # pf
                             else:
                                 out_a = -np.imag(Fk) * scale_factor  # Pk
                                 out_b = -np.real(Fk) * scale_factor  # Qk
@@ -353,15 +355,22 @@ class Prep(FilterModule):
                              (timestamp_to_human(iv_data[0][0]), processed, rows))
             """
             iv.consume(processed)
-            rows_processed += processed
-            if(nrows > 0 and rows_processed >= nrows):
-                break        
 
-            
+            # if production is stalled check to see if the sources have stopped
+            if processed == 0:
+                if iv.closed or zc.closed:
+                    break
+
+        if parsed_args.merge:
+            await output.flush_cache()
+        else:
+            for p in ph_outputs:
+                await p.flush_cache()
+
 def main():
-    filter = Prep()
-    filter.start()
+    my_filter = Prep()
+    my_filter.start()
+
 
-    
 if __name__ == "__main__":
     main()
