@@ -2,7 +2,8 @@
 Reads data from usb or ethstream device
 """
 
-from joule import ReaderModule, yesno
+from joule import ReaderModule
+from joule.utilities import yesno
 from .serialcapture import SerialCapture
 from .ethstreamcapture import EthstreamCapture
 from .errors import CaptureError
