@@ -1,13 +1,15 @@
 import asyncio
 import numpy as np
-from .errors import CaptureError
-from joule.utils.time import (timestamp_to_human,
-                              seconds_to_timestamp, now as time_now)
 import logging
 import sys
 
+from joule.utilities import (timestamp_to_human,
+                              seconds_to_timestamp, time_now)
+
+from .errors import CaptureError
+
 ROW_BYTES = 6 * 2   # 6 channels, 2 byte ints
-ROWS_PER_BLOCK = 1000  # read ~8 blocks per second
+ROWS_PER_BLOCK = 8000  # read ~8 blocks per second
 BLOCK_SIZE = ROW_BYTES * ROWS_PER_BLOCK
 
 
@@ -61,7 +63,7 @@ class EthstreamCapture():
                "-a", self.ip_address,
                "-r", "8000",
                "-C", "0,1,2,3,4,5",
-               "-L", "-B"]
+               "-L", "-B", "-o"]
         create = asyncio.create_subprocess_exec(
             *cmd,
             stdin=asyncio.subprocess.DEVNULL,
@@ -70,7 +72,7 @@ class EthstreamCapture():
         return await create
 
     def _parse(self, raw):
-        if(len(raw) != BLOCK_SIZE):
+        if len(raw) != BLOCK_SIZE:
             raise CaptureError("short read from ethstream process")
         # parse from string: 2 byte units in big endian
         data = np.frombuffer(raw, dtype=np.uint16)
