@@ -10,9 +10,9 @@ CAL_DIR = os.path.join(os.path.dirname(
 
 class TestMeter(unittest.TestCase):
 
-    @mock.patch("nilm.meter.storage.Client", autospec=True)
-    def setUp(self, client):
-        self.instance = client.return_value
+    @mock.patch("nilm.meter.storage.requests.get", autospec=True)
+    def setUp(self, get):
+        self.instance = get.return_value
         # values from bucket
         self.instance.dbinfo = mock.Mock(
             return_value={"path":     '/home/nilmdb',
@@ -38,4 +38,3 @@ class TestMeter(unittest.TestCase):
         return os.path.join(os.path.dirname(
             __file__), 'files', 'good_configs', name+'.yml')
 
-    
