@@ -5,8 +5,8 @@ import asynctest
 from unittest import mock
 import numpy as np
 
-from nilm.readers.ethstreamcapture import EthstreamCapture
-from joule import LocalNumpyPipe
+from nilm.readers import ethstreamcapture
+from joule import LocalPipe
 
 
 ETHSTREAM_DUMP = os.path.join(os.path.dirname(
@@ -22,11 +22,14 @@ class TestEthstreamCaptureCmd(unittest.TestCase):
     def test_starts_ethstream(self):
 
         mock_proc = mock.Mock()
+
         mock_proc.stdout.readexactly = asynctest.CoroutineMock(
             return_value=self.ethstream_data)
-        ec = EthstreamCapture("192.168.1.209")
+        # override default to match capture file
+        ethstreamcapture.BLOCK_SIZE = 12000
+        ec = ethstreamcapture.EthstreamCapture("192.168.1.209")
         ec._start_meter = asynctest.CoroutineMock(return_value=mock_proc)
-        npipe_output = LocalNumpyPipe("raw", layout="uint16_6")
+        npipe_output = LocalPipe(layout="uint16_6", name="raw")
 
         async def output_func(data):
             # check data output
